from setuptools import setup

setup(name='edr_distributions',
      version='1.0',
      description='Gaussian distributions',
      packages=['edr_distributions'],
      author = 'Edenilson Ruiz',
	  author_email = 'ruiz.edenilson@gmail.com',
      zip_safe=False)
